@@ -1,9 +1,10 @@
 from .mintparams import MINTParams
 from .minttarget import MINTTarget
-from .mintlayer import  MINTLayer
+from .mintlayer import MINTLayer, MINTLayerType
 from .mintterminal import MINTTerminal
 from .mintconnection import MINTConnection
 from .mintcomponent import MINTComponent
 from .mintcompiler import MINTCompiler
 from .mintdevice import MINTDevice
-from .mintnode import MINTNode
\ No newline at end of file
+from .mintnode import MINTNode
+from .mintvia import MINTVia
\ No newline at end of file
